@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package App::Cmd::Tester;
 {
-  $App::Cmd::Tester::VERSION = '0.313';
+  $App::Cmd::Tester::VERSION = '0.314';
 }
 
 # ABSTRACT: for capturing the result of running an app
@@ -28,6 +28,28 @@ sub result_class { 'App::Cmd::Tester::Result' }
 sub test_app {
   my ($class, $app, $argv) = @_;
 
+  $app = $app->new unless ref($app) or $app->isa('App::Cmd::Simple');
+
+  my $result = $class->_run_with_capture($app, $argv);
+
+  my $error = $result->{error};
+
+  my $exit_code = defined $error ? ((0+$!)||-1) : 0;
+
+  if ($error and eval { $error->isa('App::Cmd::Tester::Exited') }) {
+    $exit_code = $$error;
+  }
+
+  $class->result_class->new({
+    app    => $app,
+    exit_code => $exit_code,
+    %$result,
+  });
+}
+
+sub _run_with_capture {
+  my ($class, $app, $argv) = @_;
+
   require IO::TieCombine;
   my $hub = IO::TieCombine->new;
 
@@ -36,8 +58,6 @@ sub test_app {
 
   my $run_rv;
 
-  $app = $app->new unless ref($app) or $app->isa('App::Cmd::Simple');
-
   my $ok = eval {
     local $TEST_IN_PROGRESS = 1;
     local @ARGV = @$argv;
@@ -47,27 +67,19 @@ sub test_app {
 
   my $error = $ok ? undef : $@;
 
-  my $exit_code = defined $error ? ((0+$!)||-1) : 0;
-
-  if ($error and eval { $error->isa('App::Cmd::Tester::Exited') }) {
-    $exit_code = $$error;
-  }
-
-  $class->result_class->new({
-    app    => $app,
+  return {
     stdout => $hub->slot_contents('stdout'),
     stderr => $hub->slot_contents('stderr'),
     output => $hub->combined_contents,
     error  => $error,
     run_rv => $run_rv,
-    exit_code => $exit_code
-  });
+  };
 }
 
 {
   package App::Cmd::Tester::Result;
 {
-  $App::Cmd::Tester::Result::VERSION = '0.313';
+  $App::Cmd::Tester::Result::VERSION = '0.314';
 }
 
   sub new {
@@ -86,7 +98,7 @@ sub test_app {
 {
   package App::Cmd::Tester::Exited;
 {
-  $App::Cmd::Tester::Exited::VERSION = '0.313';
+  $App::Cmd::Tester::Exited::VERSION = '0.314';
 }
   sub throw {
     my ($class, $code) = @_;
@@ -106,7 +118,7 @@ App::Cmd::Tester - for capturing the result of running an app
 
 =head1 VERSION
 
-version 0.313
+version 0.314
 
 =head1 SYNOPSIS
 
@@ -168,7 +180,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo Signes.
+This software is copyright (c) 2012 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
